"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.prefixWithOpUp = void 0;
const algosdk_1 = require("algosdk");
/**
 *
 * Given a transaction or transaction group, prefixes it with appl call to increase opcode budget and returns the new
 * transaction group.
 * A lot of the lending operations require additional opcode cost so use this to increase the budget.
 *
 * @param opup - opup applications
 * @param userAddr - account address for the user
 * @param transactions - transaction(s) to prefix opup to
 * @param numInnerTransactions - number of inner transactions to issue (remaining opcode is 691 + 689 * num.inner.txns)
 * @param params - suggested params for the transactions with the fees overwritten
 * @returns Transaction[] transaction group with opup prefixed
 */
function prefixWithOpUp(opup, userAddr, transactions, numInnerTransactions, params) {
    if (!Number.isInteger(numInnerTransactions) || numInnerTransactions > 256) {
        throw Error("Invalid number of inner transactions");
    }
    const { callerAppId, baseAppId } = opup;
    const fee = (numInnerTransactions + 1) * 1000;
    const prefix = (0, algosdk_1.makeApplicationNoOpTxn)(userAddr, Object.assign(Object.assign({}, params), { flatFee: true, fee }), callerAppId, [(0, algosdk_1.encodeUint64)(numInnerTransactions)], undefined, [baseAppId]);
    const txns = Array.isArray(transactions) ? transactions : [transactions];
    return [prefix, ...txns].map((txn) => {
        txn.group = undefined;
        return txn;
    });
}
exports.prefixWithOpUp = prefixWithOpUp;
//# sourceMappingURL=opup.js.map