import { Algodv2, Indexer, SuggestedParams, Transaction } from "algosdk";
import { LPToken, Oracle, OraclePrices } from "./types";
/**
 *
 * Returns oracle prices for given oracle and provided assets.
 *
 * @param client - Algorand client to query
 * @param oracle - oracle to query
 * @param assetIds - assets ids to get prices for, if undefined then returns all prices
 * @returns OraclePrices oracle prices
 */
declare function getOraclePrices(client: Algodv2 | Indexer, oracle: Oracle, assetIds?: number[]): Promise<OraclePrices>;
/**
 *
 * Returns a group transaction to refresh the given assets.
 *
 * @param oracle - oracle applications to use
 * @param userAddr - account address for the user
 * @param lpAssets - list of lp assets
 * @param baseAssetIds - list of base asset ids (non-lp assets)
 * @param params - suggested params for the transactions with the fees overwritten
 * @returns Transaction[] refresh prices group transaction
 */
declare function prepareRefreshPricesInOracleAdapter(oracle: Oracle, userAddr: string, lpAssets: LPToken[], baseAssetIds: number[], params: SuggestedParams): Transaction[];
export { getOraclePrices, prepareRefreshPricesInOracleAdapter };
//# sourceMappingURL=oracle.d.ts.map