/// <reference types="node" />
import { Algodv2, Indexer, SuggestedParams, Transaction } from "algosdk";
import { Box, TealKeyValue } from "algosdk/dist/types/client/v2/algod/models/types";
declare const enc: TextEncoder;
/**
 * Transfer algo or asset. 0 assetId indicates algo transfer, else asset transfer.
 */
declare function transferAlgoOrAsset(assetId: number, from: string, to: string, amount: number | bigint, params: SuggestedParams): Transaction;
declare const signer: () => Promise<never[]>;
declare function unixTime(): number;
/**
 * Wraps a call to Algorand client (algod/indexer) and returns global state
 */
declare function getApplicationGlobalState(client: Algodv2 | Indexer, appId: number): Promise<{
    currentRound?: number;
    globalState?: TealKeyValue[];
}>;
/**
 * Wraps a call to Algorand client (algod/indexer) and returns local state
 */
declare function getAccountApplicationLocalState(client: Algodv2 | Indexer, appId: number, addr: string): Promise<{
    currentRound?: number;
    localState?: TealKeyValue[];
}>;
/**
 * Wraps a call to Algorand client (algod/indexer) and returns box value
 */
declare function getApplicationBox(client: Algodv2 | Indexer, appId: number, boxName: Uint8Array): Promise<Box>;
/**
 * Wraps a call to Algorand client (algod/indexer) and returns account details
 */
declare function getAccountDetails(client: Algodv2 | Indexer, addr: string): Promise<{
    currentRound?: number;
    isOnline: boolean;
    holdings: Map<number, bigint>;
}>;
/**
 * Convert an int to its hex representation with a fixed length of 8 bytes.
 */
declare function fromIntToBytes8Hex(num: number | bigint): string;
/**
 * Convert an int to its hex representation with a fixed length of 1 byte.
 */
declare function fromIntToByteHex(num: number | bigint): string;
declare function getParsedValueFromState(state: TealKeyValue[], key: string, encoding?: BufferEncoding): string | bigint | undefined;
declare function parseUint64s(base64Value: string): bigint[];
declare function parseUint8s(base64Value: string): bigint[];
declare function parseBitsAsBooleans(base64Value: string): boolean[];
declare function addEscrowNoteTransaction(userAddr: string, escrowAddr: string, appId: number, notePrefix: string, params: SuggestedParams): Transaction;
declare function removeEscrowNoteTransaction(escrowAddr: string, userAddr: string, notePrefix: string, params: SuggestedParams): Transaction;
export { enc, transferAlgoOrAsset, signer, unixTime, getApplicationGlobalState, getAccountApplicationLocalState, getApplicationBox, getAccountDetails, fromIntToBytes8Hex, fromIntToByteHex, getParsedValueFromState, parseUint64s, parseUint8s, parseBitsAsBooleans, addEscrowNoteTransaction, removeEscrowNoteTransaction, };
//# sourceMappingURL=utils.d.ts.map