import { Algodv2, SuggestedParams, Transaction } from "algosdk";
import { ConsensusConfig, ConsensusState } from "./types";
/**
 *
 * Returns information regarding the given consensus application.
 *
 * @param algodClient - Algorand client to query
 * @param consensusConfig - consensus application and xALGO config
 * @returns ConsensusState current state of the consensus application
 */
declare function getConsensusState(algodClient: Algodv2, consensusConfig: ConsensusConfig): Promise<ConsensusState>;
declare function prepareDummyTransaction(consensusConfig: ConsensusConfig, senderAddr: string, params: SuggestedParams): Transaction;
/**
 *
 * Returns a group transaction to stake ALGO and get xALGO immediately.
 *
 * @param consensusConfig - consensus application and xALGO config
 * @param consensusState - current state of the consensus application
 * @param senderAddr - account address for the sender
 * @param amount - amount of ALGO to send
 * @param minReceivedAmount - min amount of xALGO expected to receive
 * @param params - suggested params for the transactions with the fees overwritten
 * @param proposerAllocations - determines which proposers the ALGO sent goes to
 * @param note - optional note to distinguish who is the minter (must pass to be eligible for revenue share)
 * @returns Transaction[] stake transactions
 */
declare function prepareImmediateStakeTransactions(consensusConfig: ConsensusConfig, consensusState: ConsensusState, senderAddr: string, amount: number | bigint, minReceivedAmount: number | bigint, params: SuggestedParams, proposerAllocations?: import("./types").ProposerAllocations, note?: Uint8Array): Transaction[];
/**
 *
 * Returns a group transaction to stake ALGO and get xALGO after 320 rounds.
 *
 * @param consensusConfig - consensus application and xALGO config
 * @param consensusState - current state of the consensus application
 * @param senderAddr - account address for the sender
 * @param amount - amount of ALGO to send
 * @param params - suggested params for the transactions with the fees overwritten
 * @param includeBoxMinBalancePayment - whether to include ALGO payment to app for box min balance
 * @param proposerAllocations - determines which proposers the ALGO sent goes to
 * @param note - optional note to distinguish who is the minter (must pass to be eligible for revenue share)
 * @returns Transaction[] stake transactions
 */
declare function prepareDelayedStakeTransactions(consensusConfig: ConsensusConfig, consensusState: ConsensusState, senderAddr: string, amount: number | bigint, params: SuggestedParams, includeBoxMinBalancePayment?: boolean, proposerAllocations?: import("./types").ProposerAllocations, note?: Uint8Array): Transaction[];
/**
 *
 * Returns a group transaction to claim xALGO from delayed stake after 320 rounds.
 *
 * @param consensusConfig - consensus application and xALGO config
 * @param consensusState - current state of the consensus application
 * @param senderAddr - account address for the sender
 * @param receiverAddr - account address for the receiver
 * @param nonce - what was used to generate the delayed mint box
 * @param params - suggested params for the transactions with the fees overwritten
 * @returns Transaction[] stake transactions
 */
declare function prepareClaimDelayedStakeTransactions(consensusConfig: ConsensusConfig, consensusState: ConsensusState, senderAddr: string, receiverAddr: string, nonce: Uint8Array, params: SuggestedParams): Transaction[];
/**
 *
 * Returns a group transaction to unstake xALGO and get ALGO.
 *
 * @param consensusConfig - consensus application and xALGO config
 * @param consensusState - current state of the consensus application
 * @param senderAddr - account address for the sender
 * @param amount - amount of xALGO to send
 * @param minReceivedAmount - min amount of ALGO expected to receive
 * @param params - suggested params for the transactions with the fees overwritten
 * @param proposerAllocations - determines which proposers the ALGO received comes from
 * @param note - optional note to distinguish who is the burner (must pass to be eligible for revenue share)
 * @returns Transaction[] unstake transactions
 */
declare function prepareUnstakeTransactions(consensusConfig: ConsensusConfig, consensusState: ConsensusState, senderAddr: string, amount: number | bigint, minReceivedAmount: number | bigint, params: SuggestedParams, proposerAllocations?: import("./types").ProposerAllocations, note?: Uint8Array): Transaction[];
export { getConsensusState, prepareDummyTransaction, prepareImmediateStakeTransactions, prepareDelayedStakeTransactions, prepareClaimDelayedStakeTransactions, prepareUnstakeTransactions, };
//# sourceMappingURL=consensus.d.ts.map