"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeEscrowNoteTransaction = exports.addEscrowNoteTransaction = exports.parseBitsAsBooleans = exports.parseUint8s = exports.parseUint64s = exports.getParsedValueFromState = exports.fromIntToByteHex = exports.fromIntToBytes8Hex = exports.getAccountDetails = exports.getApplicationBox = exports.getAccountApplicationLocalState = exports.getApplicationGlobalState = exports.unixTime = exports.signer = exports.transferAlgoOrAsset = exports.enc = void 0;
const algosdk_1 = require("algosdk");
const enc = new TextEncoder();
exports.enc = enc;
/**
 * Transfer algo or asset. 0 assetId indicates algo transfer, else asset transfer.
 */
function transferAlgoOrAsset(assetId, from, to, amount, params) {
    return assetId !== 0
        ? (0, algosdk_1.makeAssetTransferTxnWithSuggestedParamsFromObject)({
            from,
            to,
            amount,
            suggestedParams: params,
            assetIndex: assetId,
        })
        : (0, algosdk_1.makePaymentTxnWithSuggestedParamsFromObject)({ from, to, amount, suggestedParams: params });
}
exports.transferAlgoOrAsset = transferAlgoOrAsset;
const signer = () => __awaiter(void 0, void 0, void 0, function* () { return []; });
exports.signer = signer;
function unixTime() {
    return Math.floor(Date.now() / 1000);
}
exports.unixTime = unixTime;
/**
 * Wraps a call to Algorand client (algod/indexer) and returns global state
 */
function getApplicationGlobalState(client, appId) {
    return __awaiter(this, void 0, void 0, function* () {
        const res = yield (client instanceof algosdk_1.Algodv2
            ? client.getApplicationByID(appId)
            : client.lookupApplications(appId)).do();
        // algod https://developer.algorand.org/docs/rest-apis/algod/#application
        // indexer https://developer.algorand.org/docs/rest-apis/indexer/#lookupapplicationbyid-response-200
        const app = client instanceof algosdk_1.Algodv2 ? res : res["application"];
        return {
            currentRound: res["current-round"],
            globalState: app["params"]["global-state"],
        };
    });
}
exports.getApplicationGlobalState = getApplicationGlobalState;
/**
 * Wraps a call to Algorand client (algod/indexer) and returns local state
 */
function getAccountApplicationLocalState(client, appId, addr) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const res = yield (client instanceof algosdk_1.Algodv2
            ? client.accountApplicationInformation(addr, appId)
            : client.lookupAccountAppLocalStates(addr).applicationID(appId)).do();
        // algod https://developer.algorand.org/docs/rest-apis/algod/#accountapplicationinformation-response-200
        // indexer https://developer.algorand.org/docs/rest-apis/indexer/#lookupaccountapplocalstates-response-200
        const localState = client instanceof algosdk_1.Algodv2 ? res["app-local-state"] : (_a = res["apps-local-states"]) === null || _a === void 0 ? void 0 : _a.find(({ id }) => id === appId);
        return {
            currentRound: res["current-round"],
            localState: localState["key-value"],
        };
    });
}
exports.getAccountApplicationLocalState = getAccountApplicationLocalState;
/**
 * Wraps a call to Algorand client (algod/indexer) and returns box value
 */
function getApplicationBox(client, appId, boxName) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield (client instanceof algosdk_1.Algodv2
            ? client.getApplicationBoxByName(appId, boxName)
            : client.lookupApplicationBoxByIDandName(appId, boxName)).do();
    });
}
exports.getApplicationBox = getApplicationBox;
/**
 * Wraps a call to Algorand client (algod/indexer) and returns account details
 */
function getAccountDetails(client, addr) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const holdings = new Map();
        try {
            const res = yield (client instanceof algosdk_1.Algodv2
                ? client.accountInformation(addr)
                : client.lookupAccountByID(addr).exclude("apps-local-state,created-apps")).do();
            // algod https://developer.algorand.org/docs/rest-apis/algod/#account
            // indexer https://developer.algorand.org/docs/rest-apis/indexer/#lookupaccountbyid-response-200
            const account = client instanceof algosdk_1.Algodv2 ? res : res["account"];
            const assets = account["assets"] || [];
            holdings.set(0, BigInt(account["amount"])); // includes min balance
            assets.forEach(({ "asset-id": assetId, amount }) => holdings.set(assetId, BigInt(amount)));
            return {
                currentRound: res["current-round"],
                isOnline: account["status"] === "Online",
                holdings,
            };
        }
        catch (e) {
            if (e.status === 404 && ((_b = (_a = e.response) === null || _a === void 0 ? void 0 : _a.text) === null || _b === void 0 ? void 0 : _b.includes("no accounts found for address"))) {
                holdings.set(0, BigInt(0));
                return {
                    isOnline: false,
                    holdings,
                };
            }
            throw e;
        }
    });
}
exports.getAccountDetails = getAccountDetails;
/**
 * Convert an int to its hex representation with a fixed length of 8 bytes.
 */
function fromIntToBytes8Hex(num) {
    return num.toString(16).padStart(16, "0");
}
exports.fromIntToBytes8Hex = fromIntToBytes8Hex;
/**
 * Convert an int to its hex representation with a fixed length of 1 byte.
 */
function fromIntToByteHex(num) {
    return num.toString(16).padStart(2, "0");
}
exports.fromIntToByteHex = fromIntToByteHex;
function encodeToBase64(str, encoding = "utf8") {
    return Buffer.from(str, encoding).toString("base64");
}
function getParsedValueFromState(state, key, encoding = "utf8") {
    const encodedKey = encoding ? encodeToBase64(key, encoding) : key;
    const keyValue = state.find((entry) => entry.key === encodedKey);
    if (keyValue === undefined)
        return;
    const { value } = keyValue;
    if (value.type === 1)
        return value.bytes;
    if (value.type === 2)
        return BigInt(value.uint);
    return;
}
exports.getParsedValueFromState = getParsedValueFromState;
function parseUint64s(base64Value) {
    const value = Buffer.from(base64Value, "base64").toString("hex");
    // uint64s are 8 bytes each
    const uint64s = [];
    for (let i = 0; i < value.length; i += 16) {
        uint64s.push(BigInt("0x" + value.slice(i, i + 16)));
    }
    return uint64s;
}
exports.parseUint64s = parseUint64s;
function parseUint8s(base64Value) {
    const value = Buffer.from(base64Value, "base64").toString("hex");
    // uint8s are 1 byte each
    const uint8s = [];
    for (let i = 0; i < value.length; i += 2) {
        uint8s.push(BigInt("0x" + value.slice(i, i + 2)));
    }
    return uint8s;
}
exports.parseUint8s = parseUint8s;
function parseBitsAsBooleans(base64Value) {
    const value = Buffer.from(base64Value, "base64").toString("hex");
    const bits = ("00000000" + Number("0x" + value).toString(2)).slice(-8);
    const bools = [];
    for (let i = 0; i < bits.length; i++) {
        bools.push(Boolean(parseInt(bits[i])));
    }
    return bools;
}
exports.parseBitsAsBooleans = parseBitsAsBooleans;
function addEscrowNoteTransaction(userAddr, escrowAddr, appId, notePrefix, params) {
    const note = Uint8Array.from([...enc.encode(notePrefix), ...(0, algosdk_1.decodeAddress)(escrowAddr).publicKey]);
    return (0, algosdk_1.makePaymentTxnWithSuggestedParamsFromObject)({
        from: userAddr,
        to: (0, algosdk_1.getApplicationAddress)(appId),
        amount: 0,
        note,
        suggestedParams: params,
    });
}
exports.addEscrowNoteTransaction = addEscrowNoteTransaction;
function removeEscrowNoteTransaction(escrowAddr, userAddr, notePrefix, params) {
    const note = Uint8Array.from([...enc.encode(notePrefix), ...(0, algosdk_1.decodeAddress)(escrowAddr).publicKey]);
    return (0, algosdk_1.makePaymentTxnWithSuggestedParamsFromObject)({
        from: escrowAddr,
        to: userAddr,
        amount: 0,
        closeRemainderTo: userAddr,
        note,
        suggestedParams: params,
    });
}
exports.removeEscrowNoteTransaction = removeEscrowNoteTransaction;
//# sourceMappingURL=utils.js.map